@@ -26,8 +26,10 @@ class TestBTM(unittest.TestCase):
         biterms = btm.get_biterms(docs_vec)
 
         LOGGER.info('Modeling started')
+        topics_num = 8
         model = btm.BTM(
-            X, vocabulary, seed=12321, T=8, W=vocabulary.size, M=20, alpha=50/8, beta=0.01)
+            X, vocabulary, seed=12321, T=topics_num, W=vocabulary.size,
+            M=20, alpha=50/topics_num, beta=0.01)
         # t1 = time.time()
         model.fit(biterms, iterations=20)
         # LOGGER.info(model.theta_)
@@ -35,13 +37,19 @@ class TestBTM(unittest.TestCase):
         # LOGGER.info(t2 - t1)
         self.assertIsInstance(model.matrix_topics_words_, np.ndarray)
         self.assertTupleEqual(
-            model.matrix_topics_words_.shape, (8, vocabulary.size))
+            model.matrix_topics_words_.shape, (topics_num, vocabulary.size))
         LOGGER.info('Modeling finished')
         # top_words = btm.get_top_topic_words(model)
         # LOGGER.info(top_words)
 
+        LOGGER.info('Model saving started')
+        with open('model.pickle', 'wb') as file:
+            self.assertIsNone(pkl.dump(model, file))
+        LOGGER.info('Model saving finished')
+
         LOGGER.info('Inference started')
-        p_zd = model.transform(docs_vec)
+        p_zd = model.transform(docs_vec[:1000])
+        self.assertTupleEqual(p_zd.shape, (1000, topics_num))
         # LOGGER.info(p_zd)
         LOGGER.info('Inference "sum_b" finished')
         p_zd = model.transform(docs_vec, infer_type='sum_w')
@@ -51,24 +59,24 @@ class TestBTM(unittest.TestCase):
         # LOGGER.info(p_zd)
         LOGGER.info('Inference "mix" finished')
 
-        LOGGER.info('Perplexity started')
+        LOGGER.info('Perplexity testing started')
         perplexity = btm.perplexity(model.matrix_topics_words_, p_zd, X, 8)
+        self.assertTrue(perplexity, model.perplexity_)
         self.assertIsInstance(perplexity, float)
         self.assertNotEqual(perplexity, 0.)
-        LOGGER.info('Perplexity finished')
+        LOGGER.info('Perplexity testing finished')
 
-        LOGGER.info('Coherence started')
+        LOGGER.info('Coherence testing started')
         coherence = btm.coherence(model.matrix_topics_words_, X, M=20)
+        self.assertTrue(np.allclose(coherence, model.coherence_))
         self.assertIsInstance(coherence, np.ndarray)
         self.assertGreater(coherence.shape[0], 0)
-        LOGGER.info('Coherence finished')
+        LOGGER.info('Coherence testing finished')
 
-        LOGGER.info('Model saving/loading started')
-        with open('model.pickle', 'wb') as file:
-            self.assertIsNone(pkl.dump(model, file))
+        LOGGER.info('Model loading started')
         with open('model.pickle', 'rb') as file:
             self.assertIsInstance(pkl.load(file), btm._btm.BTM)
-        LOGGER.info('Model saving/loading finished')
+        LOGGER.info('Model loading finished')
 
 
 if __name__ == '__main__':
